App

Struct App 

pub struct App {
    base: AppBase<ServerImpl<Details>>,
    master_enc_key_part: PrivateKey,
    master_enc_key_part_inv: Scalar,
    pseud_factor_secret: B64UU,
}

Fields

base: AppBase<ServerImpl<Details>>master_enc_key_part: PrivateKeymaster_enc_key_part_inv: Scalarpseud_factor_secret: B64UU

Implementations

Source

impl App

async fn handle_hub_ping( app: Rc<Self>, signed_req: Json<TicketSigned<PingReq>>, ) -> Result<PingResp>

async fn handle_ehpp(app: Rc<Self>, req: Json<EhppReq>) -> Result<EhppResp>

Implements EhppEP

Methods from Deref<Target = AppBase<ServerImpl<Details>>>

pub async fn get_object<T>( &self, id: &T::Identifier, ) -> Result<Option<(T, UpdateVersion)>>
where T: ObjectDetails,

Tries to retrieve an object of type T from this server’s object store with the given id, returning Ok(None) if no such object exists.

pub async fn put_object<T>( &self, obj: &T, update: Option<UpdateVersion>, ) -> Result<Option<UpdateVersion>>
where T: ObjectDetails,

Attempts to put an object of type T into the object store, only overwriting the object that is already present when the version of the to-be-overwritten object is passed via update.

Returs Ok(None) when there is already an object present in the store with that id and type, but its version was not specified in update.

pub async fn delete_object<T>(&self, id: T::Identifier) -> Result<bool>
where T: ObjectDetails,

Attempts to delete an object with the given Id; returns true when an object was deleted, and false when no object with the given id was found.

pub fn running_state_or_please_retry( &self, ) -> Result<&RunningState<S::ExtraRunningState>, ErrorCode>

Returns the current RunningState of this server when available. Otherwise returns api::ErrorCode::PleaseRetry.

pub fn running_state_or_internal_error( &self, ) -> Result<&RunningState<S::ExtraRunningState>, ErrorCode>

Returns the current RunningState of this server when available. Otherwise returns api::ErrorCode::InternalError.